@@ -84,6 +84,7 @@ new KinesisFirehoseToAnalyticsAndS3(scope: Construct, id: string, props: Kinesis
 |kinesisAnalyticsProps?|[`kinesisAnalytics.CfnApplicationProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesisanalytics.CfnApplicationProps.html)|Optional user-provided props to override the default props for the Kinesis Analytics application.|
 |existingBucketObj?|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.|
 |bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|User provided props to override the default props for the S3 Bucket.|
+|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
 
 ## Pattern Properties
 
@@ -166,6 +167,7 @@ class KinesisFirehoseToAnalyticsAndS3(
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         kinesis_analytics_props: typing.Optional[aws_cdk.aws_kinesisanalytics.CfnApplicationProps] = None,
         kinesis_firehose_props: typing.Any = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
@@ -174,6 +176,7 @@ class KinesisFirehoseToAnalyticsAndS3(
         :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
         :param kinesis_analytics_props: Optional user-provided props to override the default props for the Kinesis Analytics application. Default: - Default props are used.
         :param kinesis_firehose_props: Optional user-provided props to override the default props for the Kinesis Firehose delivery stream. Default: - Default props are used.
+        :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
 
         :access: public
         :since: 0.8.0
@@ -184,6 +187,7 @@ class KinesisFirehoseToAnalyticsAndS3(
             existing_bucket_obj=existing_bucket_obj,
             kinesis_analytics_props=kinesis_analytics_props,
             kinesis_firehose_props=kinesis_firehose_props,
+            log_group_props=log_group_props,
         )
 
         jsii.create(KinesisFirehoseToAnalyticsAndS3, self, [scope, id, props])
@@ -227,6 +231,7 @@ class KinesisFirehoseToAnalyticsAndS3(
         "existing_bucket_obj": "existingBucketObj",
         "kinesis_analytics_props": "kinesisAnalyticsProps",
         "kinesis_firehose_props": "kinesisFirehoseProps",
+        "log_group_props": "logGroupProps",
     },
 )
 class KinesisFirehoseToAnalyticsAndS3Props:
@@ -237,6 +242,7 @@ class KinesisFirehoseToAnalyticsAndS3Props:
         existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
         kinesis_analytics_props: typing.Optional[aws_cdk.aws_kinesisanalytics.CfnApplicationProps] = None,
         kinesis_firehose_props: typing.Any = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
         """The properties for the KinesisFirehoseToAnalyticsAndS3 class.
 
@@ -244,11 +250,14 @@ class KinesisFirehoseToAnalyticsAndS3Props:
         :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
         :param kinesis_analytics_props: Optional user-provided props to override the default props for the Kinesis Analytics application. Default: - Default props are used.
         :param kinesis_firehose_props: Optional user-provided props to override the default props for the Kinesis Firehose delivery stream. Default: - Default props are used.
+        :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         """
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(kinesis_analytics_props, dict):
             kinesis_analytics_props = aws_cdk.aws_kinesisanalytics.CfnApplicationProps(**kinesis_analytics_props)
+        if isinstance(log_group_props, dict):
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
@@ -258,6 +267,8 @@ class KinesisFirehoseToAnalyticsAndS3Props:
             self._values["kinesis_analytics_props"] = kinesis_analytics_props
         if kinesis_firehose_props is not None:
             self._values["kinesis_firehose_props"] = kinesis_firehose_props
+        if log_group_props is not None:
+            self._values["log_group_props"] = log_group_props
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
@@ -297,6 +308,15 @@ class KinesisFirehoseToAnalyticsAndS3Props:
         result = self._values.get("kinesis_firehose_props")
         return result
 
+    @builtins.property
+    def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
+        """User provided props to override the default props for the CloudWatchLogs LogGroup.
+
+        :default: - Default props are used
+        """
+        result = self._values.get("log_group_props")
+        return result
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
